function [matched missing] = matchspikes(groundtruth, clusterspikes, varargin)
% match the ground truth (1 * N vector) with the clustered spikes (2 * M
% vector). Matched means that there was at least one spike within a certain
% time limit, default being 1ms (variable using varargin: 'MinTime'
%
% returns the matching and the number missing
%
glength = length(groundtruth) ;
[spfound temp] = size(clusterspikes) ;

mintime = 0.001 ; % 1ms default 
missing = 0 ;
matched = zeros([2 max(clusterspikes(:,1)) + 1]) ;
for i = 1: max(clusterspikes(:,1) + 1)
    matched(1,i) = i-1 ;
end

for i=1:(nargin-2)
    if ischar(varargin{i})
        switch varargin{i}
            case 'MinTime'
                mintime = varargin{i+1};
        end
    end
end

% note that clusterspikes has time in ms, but groundtruth in seconds
clusterspikes(:,2) = clusterspikes(:,2)/1000 ;

ci = 1 ; % clusterindex

for gi=1:glength % ground  truth index

    pindex = 1 ;
    possibles = [] ;
    while clusterspikes(ci,2) < (groundtruth(gi) - mintime)
        ci = ci + 1 ;
        if (ci > spfound) break; end
    end
    if (ci > spfound) ci = spfound ; end
    while abs(clusterspikes(ci,2) - groundtruth(gi)) <= mintime
        possibles(pindex,:) = clusterspikes(ci, :) ;
        pindex = pindex + 1 ;
        ci = ci + 1 ;
        if (ci > spfound) break; end
    end
    if (isempty(possibles))
        missing = missing + 1 ;
    else
        % find element of possibles with minimum distance
        for j = 1:pindex-1
            best = 1 ;
            if abs(possibles(j,2) - groundtruth(gi)) < abs(possibles(best,2) - groundtruth(gi))
                best = j ;
            end
        end
        matched(2, possibles(best,1)+1) = matched(2, possibles(best,1)+1) + 1 ;
    end
    % reset ci to something reasonable
    ci = max(1, ci-10) ;
end
        

    